@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.300040';
+$BalanceOfPower::Commands::VERSION = '0.300050';
 use v5.10;
 use Moo;
 use IO::Prompter [-stdio];
@@ -330,6 +330,11 @@ COMMANDS
         print $self->world->print_war_history();
         $result = { status => 1 };
     }
+    elsif($query eq "civil war history")
+    {
+        print $self->world->print_civil_war_history();
+        $result = { status => 1 };
+    }
     elsif($query eq "treaties")
     {
         print $self->world->print_treaties_table();
