@@ -1,5 +1,5 @@
 package BalanceOfPower::Nation;
-$BalanceOfPower::Nation::VERSION = '0.300040';
+$BalanceOfPower::Nation::VERSION = '0.300050';
 use strict;
 use v5.10;
 
@@ -67,10 +67,6 @@ has debt => (
     is => 'rw',
     default => 0
 );
-has rebel_provinces => (
-    is => 'rw',
-    default => 0
-);
 has current_year => (
     is => 'rw'
 );
@@ -340,126 +336,8 @@ sub internal_disorder_status
     }
 }
 
-sub fight_civil_war
-{
-    my $self = shift;
-    my $world = shift;
-    return undef if($self->internal_disorder_status ne 'Civil war');
-    my $government = $world->random(0, 100, "Civil war " . $self->name . ": government fight result");
-    my $rebels = $world->random(0, 100, "Civil war " . $self->name . ": rebels fight result");
-    $self->register_event("FIGHTING CIVIL WAR");
-    if($self->army >= ARMY_UNIT_FOR_CIVIL_WAR)
-    {
-        $self->add_army(-1 * ARMY_UNIT_FOR_CIVIL_WAR);
-        $government += ARMY_HELP_FOR_CIVIL_WAR;
-    }
-    if($self->government eq 'dictatorship')
-    {
-        $government += DICTATORSHIP_BONUS_FOR_CIVIL_WAR;
-    }
-    my $reb_sup;
-    my $sup;
-    if($reb_sup = $world->rebel_supported($self->name))
-    {
-        $rebels += REBEL_SUPPORT_HELP_FOR_CIVIL_WAR;
-    }
-    if($sup = $world->supported($self->name))
-    {
-        $government += SUPPORT_HELP_FOR_CIVIL_WAR;
-    }
-    if($reb_sup)
-    {
-        $world->change_diplomacy($self->name, $reb_sup->node1, -1 * DIPLOMACY_MALUS_FOR_REBEL_CIVIL_WAR_SUPPORT, "CIVIL WAR IN " . $self->name);
-    }
-    if($sup && $reb_sup)
-    {
-        $world->change_diplomacy($sup->node1, $reb_sup->node1, -1 * DIPLOMACY_MALUS_FOR_CROSSED_CIVIL_WAR_SUPPORT, "CIVIL WAR IN " . $self->name);
-    }
-    if($government > $rebels)
-    {
-        $reb_sup->casualities(1) if $reb_sup;
-        $world->rebel_military_support_garbage_collector();
-        return $self->civil_war_battle('government', $world);
-    }
-    elsif($rebels > $government)
-    {
-        $sup->casualities(1) if $sup;
-        $world->military_support_garbage_collector();
-        return $self->civil_war_battle('rebels', $world);
-    }
-    else
-    {
-        return undef;
-    }
-}
 
-sub civil_war_battle
-{
-    my $self = shift;
-    my $battle_winner = shift;
-    my $world = shift;
-    if($battle_winner eq 'government')
-    {
-        $self->rebel_provinces($self->rebel_provinces() - .5);
-    }
-    elsif($battle_winner eq 'rebels')
-    {
-        $self->rebel_provinces($self->rebel_provinces() + .5);
-    }
-    if($self->rebel_provinces == 0)
-    {
-        $self->internal_disorder(AFTER_CIVIL_WAR_INTERNAL_DISORDER);
-        $world->broadcast_event( { code => 'govwincivil',
-                                   text => "THE GOVERNMENT OF " . $self->name . " WON THE CIVIL WAR",
-                                   involved => [$self->name] }, $self->name );
-        return 'government';
-    }
-    elsif($self->rebel_provinces == PRODUCTION_UNITS->[$self->size])
-    {
-        $self->internal_disorder(AFTER_CIVIL_WAR_INTERNAL_DISORDER);
-        $world->broadcast_event( { code => 'rebwincivil',
-                                   text => "THE REBELS IN " . $self->name . " WON THE CIVIL WAR",
-                                   involved => [$self->name] }, $self->name );
-      
-        $self->rebel_provinces(0);
-        return 'rebels';
-    }
-    return undef;
-}
 
-sub win_civil_war
-{
-    my $self = shift;
-    my $winner = shift;
-    my $world = shift;
-    if($winner eq 'rebels')
-    {
-        $self->new_government($world);
-        my $rebsup = $world->rebel_supported($self->name);
-        if($rebsup)
-        {
-            my $rebel_supporter = $world->get_nation($rebsup->node1);
-            $world->stop_rebel_military_support($rebel_supporter, $self) if $rebel_supporter;
-            $world->diplomacy_exists($self->name, $rebel_supporter->name)->factor(REBEL_SUPPORTER_WINNER_FRIENDSHIP);
-            $world->create_treaty($self->name, $rebel_supporter->name, 'alliance');
-            $world->broadcast_event({ code => 'alliancetreatynew',
-                                     text => "ALLIANCE BETWEEN " . $self->name . " AND " . $rebel_supporter->name, 
-                                     involved => [$self->name, $rebel_supporter->name],
-                                     values => ['rebsup'] }, $self->name, $rebel_supporter->name);
-        }
-        $world->empty_stocks($self->name);
-        $self->available_stocks(START_STOCKS->[$self->size]);
-    }
-    elsif($winner eq 'government')
-    {
-        my $rebsup = $world->rebel_supported($self->name);
-        if($rebsup)
-        {
-            my $rebel_supporter = $world->get_nation($rebsup->node1);
-            $world->stop_rebel_military_support($rebel_supporter, $self) if $rebel_supporter;
-        }
-    }  
-}
 
 sub new_government
 {
@@ -560,7 +438,7 @@ sub dump
     my $io = shift;
     my $indent = shift || "";
     print {$io} $indent . 
-                join(";", $self->name, $self->code, $self->area, $self->export_quote, $self->government, $self->government_strength, $self->size, $self->internal_disorder, $self->production_for_domestic, $self->production_for_export, $self->prestige, $self->wealth, $self->debt, $self->rebel_provinces, $self->current_year, $self->army, $self->progress, $self->available_stocks) . "\n";
+                join(";", $self->name, $self->code, $self->area, $self->export_quote, $self->government, $self->government_strength, $self->size, $self->internal_disorder, $self->production_for_domestic, $self->production_for_export, $self->prestige, $self->wealth, $self->debt, $self->current_year, $self->army, $self->progress, $self->available_stocks) . "\n";
     $self->dump_events($io, " " . $indent);
 }
 
@@ -568,22 +446,53 @@ sub load
 {
     my $self = shift;
     my $data = shift;
+    my $version = shift;
     my $nation_line = ( split /\n/, $data )[0];
-    $nation_line =~ s/^\s+//;
-    chomp $nation_line;
-    my ($name, $code, $area, $export_quote, $government, $government_strength, $size, $internal_disorder, $production_for_domestic, $production_for_export, $prestige, $wealth, $debt, $rebel_provinces, $current_year, $army, $progress, $available_stocks) = split ";", $nation_line;
+    my %init_params = $self->manage_nation_line($nation_line, $version);
     $data =~ s/^.*?\n//;
     my $events = $self->load_events($data);
-    return $self->new(name => $name, code => $code, area => $area, size => $size,
-                      export_quote => $export_quote, government => $government, government_strength => $government_strength,
-                      internal_disorder => $internal_disorder, 
-                      production_for_domestic => $production_for_domestic, production_for_export => $production_for_export,
-                      prestige => $prestige, wealth => $wealth, debt => $debt,
-                      rebel_provinces => $rebel_provinces, army => $army,
-                      current_year => $current_year,
-                      progress => $progress,
-                      events => $events,
-                      available_stocks => $available_stocks);
+    $init_params{'events'} = $events;
+    return $self->new(%init_params);
+}
+
+sub manage_nation_line
+{
+    my $self = shift;
+    my $nation_line = shift;
+    my $version = shift;
+    $nation_line =~ s/^\s+//;
+    chomp $nation_line;
+
+    my %init_params;
+    
+    if($version > 1)
+    {
+        my ($name, $code, $area, $export_quote, $government, $government_strength, $size, $internal_disorder, $production_for_domestic, $production_for_export, $prestige, $wealth, $debt, $current_year, $army, $progress, $available_stocks) = split ";", $nation_line;
+        %init_params = (name => $name, code => $code, area => $area, size => $size,
+                        export_quote => $export_quote, government => $government, government_strength => $government_strength,
+                        internal_disorder => $internal_disorder, 
+                        production_for_domestic => $production_for_domestic, production_for_export => $production_for_export,
+                        prestige => $prestige, wealth => $wealth, debt => $debt,
+                        army => $army,
+                        current_year => $current_year,
+                        progress => $progress,
+                        available_stocks => $available_stocks);
+
+    }
+    else
+    {
+        my ($name, $code, $area, $export_quote, $government, $government_strength, $size, $internal_disorder, $production_for_domestic, $production_for_export, $prestige, $wealth, $debt, $rebel_provinces, $current_year, $army, $progress, $available_stocks) = split ";", $nation_line;
+        %init_params = (name => $name, code => $code, area => $area, size => $size,
+                        export_quote => $export_quote, government => $government, government_strength => $government_strength,
+                        internal_disorder => $internal_disorder, 
+                        production_for_domestic => $production_for_domestic, production_for_export => $production_for_export,
+                        prestige => $prestige, wealth => $wealth, debt => $debt,
+                        army => $army,
+                        current_year => $current_year,
+                        progress => $progress,
+                        available_stocks => $available_stocks);
+    }
+    return %init_params;
 }
 
 1;
