@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Analyst;
-$BalanceOfPower::Role::Analyst::VERSION = '0.300040';
+$BalanceOfPower::Role::Analyst::VERSION = '0.300050';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -128,44 +128,15 @@ sub print_near_analysis
     foreach my $b (@near)
     {
         my $rel = $self->diplomacy_exists($nation, $b);
-        if(! $self->border_exists($nation, $b))
-        {
-            if($self->exists_military_support($nation, $b))
-            {
-                push @data, { nation => $b,
-                              relation => $rel,
-                              how => 'supported' };
-            }
-            else
-            {
-                my @foreign_borders = $self->get_borders($b);
-                foreach my $fb (@foreign_borders)
-                {
-                    my $other_n = $fb->destination($b);
-                    my $sups = $self->supported($other_n);
-                    if($sups)
-                    {
-                        if($sups->start($other_n) eq $nation)
-                        {
-                            push @data, { nation => $b,
-                                          relation => $rel,
-                                          how => $other_n };
-                        }
-                    }
-                }
-            }
-        }
-        else
-        {
-            push @data, { nation => $b,
-                          relation => $rel,
-                          how => "border" };
-        }
+        my $reason = $self->in_military_range($nation, $b);
+        push @data, { nation => $b,
+                      relation => $rel,
+                      how => $reason->{'how'},
+                      who => $reason->{'who'} };
     }
     BalanceOfPower::Printer::print($mode, $self, 'print_near_analysis', 
                                            { nation => $nation,
                                              near => \@data } );
-
 }
 sub print_hotspots
 {
@@ -224,6 +195,28 @@ sub print_war_history
                                    { wars => \%wars,
                                      war_names => \@war_names } );
 }
+sub print_civil_war_history
+{
+    my $self = shift;
+    my $mode = shift || 'print';
+    my %civil_wars;
+    my @civil_war_names;
+    foreach my $w (@{$self->civil_memorial})
+    {
+        my $name = $w->name . " - " . $w->start_date;
+        $civil_wars{$name} =  $w;
+        push @civil_war_names, { name => $name,
+                                 start => $w->start_date  };
+    }
+    sub civil_comp
+    {
+        compare_turns($a->{start}, $b->{start});
+    }
+    @civil_war_names = sort civil_comp @civil_war_names;
+    return BalanceOfPower::Printer::print($mode, $self, 'print_civil_war_history', 
+                                   { civil_wars => \%civil_wars,
+                                     civil_war_names => \@civil_war_names } );
+}
 sub print_treaties_table
 {
     my $self = shift;
@@ -323,4 +316,52 @@ sub print_market
                                           { market_data => \%data,
                                             nations => \@nations } );
 }
+
+sub print_wars
+{
+    my $self = shift;
+    my $nation = shift;
+    my $mode = shift || 'print';
+    my %grouped_wars;
+    foreach my $w ($self->wars->all())
+    {
+        if(! exists $grouped_wars{$w->war_id})
+        {
+            $grouped_wars{$w->war_id} = [];
+        }
+        push @{$grouped_wars{$w->war_id}}, $w; 
+    }
+    my @wars;
+    foreach my $k (keys %grouped_wars)
+    {
+        my %war;
+        $war{'name'} = $k;
+        $war{'conflicts'} = [];
+        foreach my $w ( @{$grouped_wars{$k}})
+        {
+            my %subwar;
+            $subwar{'node1'} = $w->node1;
+            $subwar{'node2'} = $w->node2;
+            my $nation1 = $self->get_nation($w->node1);
+            my $nation2 = $self->get_nation($w->node2);
+            $subwar{'army1'} = $nation1->army;
+            $subwar{'army2'} = $nation2->army;
+            $subwar{'node1_faction'} = $w->node1_faction;
+            $subwar{'node2_faction'} = $w->node2_faction;
+            push @{$war{'conflicts'}}, \%subwar;
+        }
+        push @wars, \%war;
+    }
+    my @civil_wars;
+    foreach my $n (@{$self->nation_names})
+    {
+        if($self->at_civil_war($n))
+        {
+            push @civil_wars, $n;
+        }
+    }
+    return BalanceOfPower::Printer::print($mode, $self, 'print_wars', 
+                                   { wars => \@wars,
+                                     civil_wars => \@civil_wars } );
+}
 1;
