@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Recorder;
-$BalanceOfPower::Role::Recorder::VERSION = '0.300040';
+$BalanceOfPower::Role::Recorder::VERSION = '0.300050';
 use strict;
 use v5.10;
 
@@ -10,6 +10,8 @@ use BalanceOfPower::Executive;
 requires 'dump_events';
 requires 'load_events';
 
+my $dump_version = 2;
+
 
 sub dump
 {
@@ -40,6 +42,7 @@ sub load_nations
 {
     my $self = shift;
     my $data = shift;
+    my $version = shift;
     $data .= "EOF\n";
     my $nation_data = "";
     foreach my $l (split "\n", $data)
@@ -49,7 +52,7 @@ sub load_nations
         {
             if($nation_data)
             {
-                my $nation = BalanceOfPower::Nation->load($nation_data);
+                my $nation = BalanceOfPower::Nation->load($nation_data, $version);
                 my $executive = BalanceOfPower::Executive->new( actor => $nation->name );
                 $executive->init($self);
                 $nation->executive($executive);
@@ -90,6 +93,33 @@ sub load_players
     }
 }
 
+sub load_civil_wars
+{
+    my $self = shift;
+    my $data = shift;
+    $data .= "EOF\n";
+    my $cw_data = "";
+    foreach my $l (split "\n", $data)
+    {
+
+        if($l !~ /^\s/ && $l !~ /^$/)
+        {
+            if($cw_data)
+            {
+                my $cw = BalanceOfPower::CivilWar->load($cw_data);
+                $cw->load_nation($self);
+                push @{$self->civil_wars}, $cw;
+            }
+            $cw_data = $l . "\n";
+        }
+        else
+        {
+            $cw_data .= $l . "\n";
+        }
+    }
+}
+
+
 
 sub dump_all
 {
@@ -97,6 +127,7 @@ sub dump_all
     my $file = shift || $self->savefile;
     return "No file provided" if ! $file;
     open(my $io, "> $file");
+    print {$io} "####### V$dump_version\n";
     $self->dump($io);
     print {$io} "### NATIONS\n";
     for(@{$self->nations})
@@ -124,8 +155,15 @@ sub dump_all
     $self->rebel_military_supports->dump($io);
     print {$io} "### WARS\n";
     $self->wars->dump($io);
+    print {$io} "### CIVIL WARS\n";
+    for(@{$self->civil_wars})
+    {
+        $_->dump($io);
+    }
     print {$io} "### MEMORIAL\n";
     $self->dump_memorial($io);
+    print {$io} "### CIVIL MEMORIAL\n";
+    $self->dump_civil_memorial($io);
     print {$io} "### STATISTICS\n";
     $self->dump_statistics($io);
     print {$io} "### EOF\n";
@@ -141,9 +179,30 @@ sub load_world
     my $world;
     my $target = "WORLD";
     my $data = "";
+    my $version = undef;
     for(<$dump>)
     {
         my $line = $_;
+        if(! $version)
+        {
+            if($line =~ /^####### V(.*)$/)
+            {
+                $version = $1;
+                if($version != $dump_version)
+                {
+                    say "WARNING: Dump of version $version";
+                }
+                next;
+            }
+            else
+            {
+                $version = 1;
+                if($version != $dump_version)
+                {
+                    say "WARNING: Dump of version $version";
+                }
+            }
+        }
         if($line =~ /^### (.*)$/)
         {
             my $next = $1;
@@ -154,7 +213,7 @@ sub load_world
             }
             elsif($target eq 'NATIONS')
             {
-                $world->load_nations($data);
+                $world->load_nations($data, $version);
             }
             elsif($target eq 'PLAYERS')
             {
@@ -196,10 +255,18 @@ sub load_world
                     $_->log_active(0);
                 }
             }
+            elsif($target eq 'CIVIL WARS')
+            {
+                $world->load_civil_wars($data);
+            }
             elsif($target eq 'MEMORIAL')
             {
                 $world->memorial($world->load_memorial($data));
             }
+            elsif($target eq 'CIVIL MEMORIAL')
+            {
+                $world->civil_memorial($world->load_civil_memorial($data));
+            }
             elsif($target eq 'STATISTICS')
             {
                 $world->load_statistics($data);
