@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Supporter;
-$BalanceOfPower::Role::Supporter::VERSION = '0.300040';
+$BalanceOfPower::Role::Supporter::VERSION = '0.300050';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -8,8 +8,8 @@ use BalanceOfPower::Relations::MilitarySupport;
 use BalanceOfPower::Constants ':all';
 
 requires 'get_nation';
-requires 'at_civil_war';
 requires 'war_report';
+requires 'civil_war_report';
 
 has military_supports => (
     is => 'ro',
@@ -77,6 +77,7 @@ sub start_military_support
                              involved => [$nation1->name, $nation2->name] },                                
                              $nation1->name, $nation2->name);
     $self->war_report($nation1->name . " started military support for " . $nation2->name, $nation2->name);
+    $self->civil_war_report($nation1->name . " started military support for " . $nation2->name, $nation2->name);
     $self->change_diplomacy($nation1->name, $nation2->name, DIPLOMACY_FACTOR_STARTING_SUPPORT, "STARTED MILITARY SUPPORT FROM ".$nation1->name);
 }
 sub start_rebel_military_support
@@ -85,7 +86,6 @@ sub start_rebel_military_support
     my $nation1 = shift;
     my $nation2 = shift;
     return 0 if($nation1->army < REBEL_ARMY_FOR_SUPPORT);
-    return 0 if(! $self->at_civil_war($nation2->name));
     my $precedent_sup = $self->exists_rebel_military_support($nation1->name, $nation2->name);
     if($precedent_sup)
     {
@@ -112,6 +112,7 @@ sub start_rebel_military_support
     $self->broadcast_event({ code => 'rebsupstarted',
                              text => "REBEL MILITARY SUPPORT AGAINST " . $nation2->name . " STARTED BY " . $nation1->name, 
                              involved => [$nation1->name, $nation2->name] }, $nation1->name, $nation2->name);
+    $self->civil_war_report($nation1->name . " started rebel military support in " . $nation2->name, $nation2->name);
     $self->change_diplomacy($nation1->name, $nation2->name, DIPLOMACY_FACTOR_STARTING_REBEL_SUPPORT, "STARTED REBEL MILITARY SUPPORT FROM " . $nation1->name);
 }
 sub stop_military_support
@@ -128,6 +129,7 @@ sub stop_military_support
                               text => "MILITARY SUPPORT FOR " . $node2->name . " STOPPED BY " . $node1->name, 
                               involved => [$node1->name, $node2->name] }, $node1->name, $node2->name);
     $self->war_report($node1->name . " stopped military support for " . $node2->name, $node2->name);
+    $self->civil_war_report($node1->name . " stopped military support for " . $node2->name, $node2->name);
     if(! $avoid_diplomacy)
     {
         $self->change_diplomacy($node1->name, $node2->name, -1 * DIPLOMACY_FACTOR_BREAKING_SUPPORT, "STOPPED MILITARY SUPPORT FROM " . $node1->name);
@@ -142,6 +144,7 @@ sub stop_rebel_military_support
     return if (! $milsup);
     $self->delete_rebel_military_support($node1->name, $node2->name);
     $node1->add_army($milsup->army);
+    $self->civil_war_report($node1->name . " stopped rebel military support in " . $node2->name, $node2->name);
     $self->broadcast_event({ code => 'rebsupstopped',
                              text => "REBEL MILITARY SUPPORT AGAINST " . $node2->name . " STOPPED BY " . $node1->name, 
                              involved => [$node1->name, $node2->name] }, $node1->name, $node2->name);
